@@ -1,6 +1,6 @@
 import os
 import sys
-sys.path.insert(0, '/usr/local/google_appengine')
+sys.path.insert(0, '/usr/local/gae/python')
 import dev_appserver
 dev_appserver.fix_sys_path()
 
@@ -12,12 +12,13 @@ from views import app
 from models import *
 import unittest
 import webtest
+import seeds
 import logging
 
 logger = logging.getLogger(__name__)
 
 
-class T(unittest.TestCase):
+class T(unittest.TestCase, seeds.Seeder):
 
     def setUp(self):
 
@@ -29,57 +30,7 @@ class T(unittest.TestCase):
         self.testbed.init_memcache_stub()
         self.testbed.init_user_stub()
 
-        self.user1 = User(
-            email=users.User('1@gmail.com')
-        )
-        self.user1.put()
-        self.user2 = User(
-            email=users.User('2@gmail.com')
-        )
-        self.user2.put()
-        self.post1 = Post(
-            title='a',
-            content='a',
-            user=self.user1.key
-        )
-        self.post1.put()
-        self.post2 = Post(
-            title='b',
-            content='b',
-            user=self.user1.key
-        )
-        self.post2.put()
-        self.post3 = Post(
-            title='c',
-            content='c',
-            user=self.user2.key,
-            parent=self.user2.key
-        )
-        self.post3.put()
-        self.comment1 = Comment(
-            content='d',
-            post=self.post3.key,
-            user=self.user2.key
-        )
-        self.comment1.put()
-        self.comment2 = Comment(
-            content='e',
-            post=self.post3.key,
-            user=self.user2.key
-        )
-        self.comment2.put()
-        self.tag1 = Tag(
-            name='f',
-            post=self.post3.key,
-            user=self.user2.key
-        )
-        self.tag1.put()
-        self.tag2 = Tag(
-            name='g',
-            post=self.post3.key,
-            user=self.user2.key
-        )
-        self.tag2.put()
+        self.seed()
 
         assert len(User.query().fetch(5)) == 2
         assert len(Post.query().fetch(5)) == 3
